summaryrefslogtreecommitdiffstats
path: root/parameter/SelectionCriterionType.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /parameter/SelectionCriterionType.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'parameter/SelectionCriterionType.h')
-rw-r--r--parameter/SelectionCriterionType.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/parameter/SelectionCriterionType.h b/parameter/SelectionCriterionType.h
index c004aca..bfef21e 100644
--- a/parameter/SelectionCriterionType.h
+++ b/parameter/SelectionCriterionType.h
@@ -36,48 +36,48 @@
class CSelectionCriterionType : public CElement, public ISelectionCriterionTypeInterface
{
- typedef map<string, int>::const_iterator NumToLitMapConstIt;
+ typedef std::map<std::string, int>::const_iterator NumToLitMapConstIt;
public:
CSelectionCriterionType(bool bIsInclusive);
// From ISelectionCriterionTypeInterface
- virtual bool addValuePair(int iValue, const string& strValue);
+ virtual bool addValuePair(int iValue, const std::string& strValue);
/**
* Retrieve the numerical value from the string representation of the criterion type.
*
* @param[in] strValue: criterion type value represented as a stream. If the criterion is
* inclusive, it supports more than one criterion type value delimited
* by the "|" symbol.
* @param[out] iValue: criterion type value represented as an integer.
*
* @return true if integer value retrieved from the string one, false otherwise.
*/
- virtual bool getNumericalValue(const string& strValue, int& iValue) const;
- virtual bool getLiteralValue(int iValue, string& strValue) const;
+ virtual bool getNumericalValue(const std::string& strValue, int& iValue) const;
+ virtual bool getLiteralValue(int iValue, std::string& strValue) const;
virtual bool isTypeInclusive() const;
// Value list
- string listPossibleValues() const;
+ std::string listPossibleValues() const;
// Formatted state
- virtual string getFormattedState(int iValue) const;
+ virtual std::string getFormattedState(int iValue) const;
// From CElement
- virtual string getKind() const;
+ virtual std::string getKind() const;
private:
/**
* Retrieve the numerical value from the string representation of the criterion type.
*
* @param[in] strValue: criterion type value represented as a stream. If the criterion is
* inclusive, it expects only one criterion type value.
* @param[out] iValue: criterion type value represented as an integer.
*
* @return true if integer value retrieved from the string one, false otherwise.
*/
- bool getAtomicNumericalValue(const string& strValue, int& iValue) const;
+ bool getAtomicNumericalValue(const std::string& strValue, int& iValue) const;
bool _bInclusive;
- map<string, int> _numToLitMap;
+ std::map<std::string, int> _numToLitMap;
static const std::string _strDelimiter; /**< Inclusive criterion type delimiter. */
};
@@ -36,48 +36,48 @@
/**
- * Retrieve the numerical value from the string representation of the criterion type.
+ * Retrieve the numerical value from the std::string representation of the criterion type.
*
* @param[in] strValue: criterion type value represented as a stream. If the criterion is
@@ -36,48 +36,48 @@
* @param[out] iValue: criterion type value represented as an integer.
*
- * @return true if integer value retrieved from the string one, false otherwise.
+ * @return true if integer value retrieved from the std::string one, false otherwise.
*/
@@ -36,48 +36,48 @@
private:
/**
- * Retrieve the numerical value from the string representation of the criterion type.
+ * Retrieve the numerical value from the std::string representation of the criterion type.
*
* @param[in] strValue: criterion type value represented as a stream. If the criterion is
@@ -36,48 +36,48 @@
* @param[out] iValue: criterion type value represented as an integer.
*
- * @return true if integer value retrieved from the string one, false otherwise.
+ * @return true if integer value retrieved from the std::string one, false otherwise.
*/